@@ -1,6 +1,29 @@
+
+/* 
+ *     XaoS, a fast portable realtime fractal zoomer 
+ *                  Copyright (C) 1996,1997 by
+ *
+ *      Jan Hubicka          (hubicka@paru.cas.cz)
+ *      Thomas Marsh         (tmarsh@austin.ibm.com)
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
 #include <stdio.h>
 #include <ctype.h>
 #include <stdlib.h>
+#include <malloc.h>
 #include "mktable.h"
 #include "config.h"
 #ifdef CURSES_DRIVER
@@ -352,7 +375,7 @@ unsigned CONST char font16[] =
 0, 0, 0, 0, 0, 0, 0, 0, 124, 124, 124, 124, 124, 124, 124, 0, 0, 0, 0, 0,
     0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
 #endif
-    };
+};
 #define NPARAMS 5
 #define NCHARS (128*NATTRS)
 #define TABLESIZE 65536
@@ -367,7 +390,7 @@ static unsigned short *next;
 static int first = -1;
 static int last = -1;
 #define add(i) if(next[(i)]==(i)&&last!=(i)) {if(last!=-1) next[last]=(i),last=(i); else last=first=(i);}
-#define dist(i1,i2,i3,i4,i5,y1,y2,y3,y4,y5) (3*(abs((int)(i1)-(int)(y1))+abs((int)(i2)-(int)(y2))+(abs((int)(i3)-(int)(y3))+abs((int)(i4)-(int)(y4))))+1*abs((int)(i5)-(int)(y5)))
+#define dist(i1,i2,i3,i4,i5,y1,y2,y3,y4,y5) (3*(abs((int)(i1)-(int)(y1))+abs((int)(i2)-(int)(y2))+(abs((int)(i3)-(int)(y3))+abs((int)(i4)-(int)(y4))))+abs((int)(i5)-(int)(y5)))
 #define pos(i1,i2,i3,i4) (((int)(i1)<<12)+((int)(i2)<<8)+((int)(i3)<<4)+(int)(i4))
 #define postoparams(pos,i1,i2,i3,i4) \
   ((i1)=(pos)>>12),((i2)=((pos)>>8)&15),((i3)=((pos)>>4)&15),((i4)=((pos))&15)
@@ -586,14 +609,15 @@ void mktable(void)
 		    if (ch == c || index == blocked)
 			continue;
 		    if (ch) {
+			int sum = i1 + i2 + i3 + i4;
 			dist = dist(
-				     i1, i2, i3, i4, (i1 + i2 + i3 + i4),
+				       i1, i2, i3, i4, sum,
 				       parameters[c].p[0],
 				       parameters[c].p[1],
 				       parameters[c].p[2],
 				       parameters[c].p[3],
 				       parameters[c].p[4]);
-			dist1 = dist(i1, i2, i3, i4, (i1 + i2 + i3 + i4),
+			dist1 = dist(i1, i2, i3, i4, sum,
 				     parameters[ch].p[0],
 				     parameters[ch].p[1],
 				     parameters[ch].p[2],
@@ -612,8 +636,8 @@ void mktable(void)
 	while (i != i1);
     }
     while (last != -1);
-    free(next);
-    free(parameters);
+    free((void *) next);
+    free((void *) parameters);
 }
 void setheight(int i)
 {
